######################################################################
#
# Spanish Language text and icon macros 
#
######################################################################
#
# This is the main macro file for translation when creating an 
# interface in another language.
#
# Under the 'text macros' comments are text macros of the form:
# _macroname_ [l=es] {macro value}
# Everything between the {} is the text to be translated. This text 
# may itself contain macros (i.e. characters other than space between
# underscore characters, e.g. _about:numdocs_ or _textpage_). These
# macro names occurring within text shouldn't be translated but should
# be left as they are. Underscores or curly brackets occurring 
# naturally within the text should be escaped with a leading backslash
# (i.e. '\_', '\{' or '\}).
#
# Under the 'icons' comments are macros concerned with displaying
# icons which themselves contain text.
# Above each macro (or group of macros) for an icon is a comment line
# that looks something like '## "HOME" ## top_nav_button ## chome ##'.
# The first field of the comment ("HOME" in this case) is the text
# that appears in the english version of the icon. This is the text
# that must be translated, nothing needs to be done to the macros 
# themselves. The other two fields of the comments are used by 
# automatic icon generating software which reads the newly translated
# file and generates appropriate icons.
#
# Comment lines (other than those described above) need not be 
# translated (i.e. any lines beginning with '#', like this line).
#
# The simplest way to translate this file is to save it as something
# else (e.g. french.dm) and work through translating all the text
# macro values and icon comments.
#
######################################################################


######################################################################
# Global (base) package
package Global
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textperiodicals_ [l=es] {Publicaciones periódicas}
_textsource_ [l=es] {ref. fuente: }
_textdate_ [l=es] {fecha de publicación: }
_textnumpages_ [l=es] {número de páginas: }

_textsignin_ [l=es] {conectarse}

_textdefaultcontent_ [l=es] {La página solicitada no se encontró. Por 
favor pulse el botón "Atrás" de su navegador o el botón 
"Inicio" para regresar a la Biblioteca Electrónica Greenstone.}

_textdefaulttitle_ [l=es] {Error en GSDL}

_collectionextra_ [l=es] {Esta colección contiene _about:numdocs_ documentos. 
La colección se creó hace _about:builddate_ días.}

# this is only used by the collector (where the above _collectionextra_
# macro will always be set to another value)
_collectorextra_ [l=es] {
<p>Esta colección contiene _numdocs_ _If_("_numdocs_" eq
"1",document,documents) y un total de _numbytes_.
<p><a href="_httppagex_(bsummary)">Pulse aquí</a> para visualizar el
informe de creación de esta colección.
}

_textimagecollection_ [l=es] {}
_textimageabout_ [l=es] {Página Acerca de}
_textimagehome_ [l=es] {Página Principal}
_textimagehelp_ [l=es] {Página de ayuda}
_textimagepref_ [l=es] {Página de Preferencias}
_textimagegreenstone_ [l=es] {Programa de la Biblioteca electrónica Greenstone}

_textimagesearch_ [l=es] {Buscar términos específicos}
_textimageTitle_ [l=es] {Navegar en las listas de títulos por orden alfabético}
_textimageList_ [l=es] {Navegar en la lista de documentos}
_textimageCreator_ [l=es] {Navegar en las listas de autores por orden alfabético}
_textimageSeries_ [l=es] {Navegar por número de publicación}
_textimageDate_ [l=es] {Navegar por fecha}
_textimageSubject_ [l=es] {Navegar por categorías de temas}
_textimageTo_ [l=es] {Navegar por campo «A»}
_textimageFrom_ [l=es] {Navegar por campo «De»}
_textimageOrganization_ [l=es] {Navegar por organización}
_textimageHowto_ [l=es] {Navegar por categorías "cómo"}
_textimageTopic_ [l=es] {Navegar por temas especiales}
_textimageBrowse_ [l=es] {Navegar}
_textimagePeople_ [l=es] {Navegar en las listas de personas por orden alfabético}
_textimageLanguage_ [l=es] {Navegar por lengua}
_textimageAcronym_ [l=es] {Navegar en la lista de siglas}
_textimagePhrase_ [l=es] {Navegar en la lista de frases}
_textimageArtist_ [l=es] {Navegar en la lista de artistas}
_textimageSource_ [l=es] {Navegar por nombre de fichero original}
_textimageKeyword_ [l=es] {Navegar por palabra clave}

_texticontabsearchgreen_ [l=es]   {Buscar}
_texticontabdategreen_ [l=es]     {Fechas}
_texticontabseriesgreen_ [l=es]   {Series}
_texticontabauthorgreen_ [l=es]   {Autores A-Z}
_texticontabtitlegreen_ [l=es]    {Títulos A-Z}
_texticontablistgreen_ [l=es]     {Listas}
_texticontabsubjectgreen_ [l=es]  {Temas}
_texticontabtogreen_ [l=es]       {A}
_texticontabfromgreen_ [l=es]     {De}
_texticontaborggreen_ [l=es]      {Organización}
_texticontabhowgreen_ [l=es]      {Cómo}
_texticontabtopicgreen_ [l=es]    {Temas}
_texticontabbrwsegreen_ [l=es]    {Navegar}
_texticontabbrowsgreen_ [l=es]    {Navegar}
_texticontabPeoplegreen_ [l=es]   {Personas A-Z}
_texticontabLanguagegreen_ [l=es] {Lengua}
_texticontabAcronymgreen_ [l=es]  {Siglas}
_texticontabPhrasegreen_ [l=es]   {Frases}
_texticontabArtistgreen_ [l=es]   {Artistas}
_texticontabSourcegreen_ [l=es]   {Nombres de ficheros}
_texticontabKeywordgreen_ [l=es]  {Palabras clave}

_texticontext_ [l=es] {Ver el documento}
_texticonclosedbook_ [l=es] {Abrir este documento y ver su índice de contenido}
_texticonnext_ [l=es] {Ir a la siguiente sección}
_texticonprev_ [l=es] {Ir a la sección anterior}

_texticonmidi_ [l=es] {Ver el documento en el formato MIDI}
_texticonmsword_ [l=es] {Ver el documento en el formato Microsoft Word}
_texticonpdf_  [l=es] {Ver el documento en el formato PDF}
_texticonps_  [l=es] {Ver el documento en el formato PostScript}
_texticonppt_  [l=es] {Ver el documento en el formato PowerPoint}
_texticonrtf_  [l=es] {Ver el documento en el formato RTF}
_texticonxls_  [l=es] {Ver el documento en el formato Microsoft Excel}

_page_ [l=es] {página }
_pages_ [l=es] {páginas}
_of_ [l=es] { de }
_vol_ [l=es] {Volumen}
_num_ [l=es] {número}

_textmonth00_ [l=es] {}
_textmonth01_ [l=es] {enero}
_textmonth02_ [l=es] {febrero}
_textmonth03_ [l=es] {marzo}
_textmonth04_ [l=es] {abril}
_textmonth05_ [l=es] {mayo}
_textmonth06_ [l=es] {junio}
_textmonth07_ [l=es] {julio}
_textmonth08_ [l=es] {agosto}
_textmonth09_ [l=es] {septiembre}
_textmonth10_ [l=es] {octubre}
_textmonth11_ [l=es] {noviembre}
_textmonth12_ [l=es] {diciembre}

_Document_ [l=es] {Documento}
_Section_ [l=es] {Sección}
_Paragraph_ [l=es] {Párrafo}

_magazines_ [l=es] {Revistas}

_nzdlpagefooter_ [l=es] {<p>_iconblankbar_
<p><a href="http://www.nzdl.org">Proyecto de biblioteca electrónica de Nueva
Zelandia</a>
<br><a href="http://www.cs.waikato.ac.nz/cs">Departamento de informática</a>, 
<a href="http://www.waikato.ac.nz">Universidad de Waikato</a>,
Nueva Zelandia}

#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "PRINCIPAL" ## top_nav_button ## chome ##
_httpiconchomeof_ [l=es] {_httpimg_/es/chomeof.gif}
_httpiconchomeon_ [l=es] {_httpimg_/es/chomeon.gif}

## "AYUDA" ## top_nav_button ## chelp ##
_httpiconchelpof_ [l=es] {_httpimg_/es/chelpof.gif}
_httpiconchelpon_ [l=es] {_httpimg_/es/chelpon.gif}
   
## "PREFERENCIAS" ## top_nav_button ## cpref ##
_httpiconcprefof_ [l=es] {_httpimg_/es/cprefof.gif}
_httpiconcprefon_ [l=es] {_httpimg_/es/cprefon.gif}

## "ayuda" ## green_title ## h_help ##
_httpiconhhelp_ [l=es] {_httpimg_/es/h\_help.gif}
_widthhhelp_ [l=es] {200}
_heighthhelp_ [l=es] {57}

## "autores a-z" ## nav_bar_button ## tauth ##
_httpicontauthgr_ [l=es] {_httpimg_/es/tauthgr.gif}
_httpicontauthof_ [l=es] {_httpimg_/es/tauthof.gif}
_httpicontauthon_ [l=es] {_httpimg_/es/tauthon.gif}
_widthtauthx_ [l=es] {100}

## "series" ## nav_bar_button ## tser ##
_httpicontsergr_ [l=es] {_httpimg_/es/tsergr.gif}
_httpicontserof_ [l=es] {_httpimg_/es/tserof.gif}
_httpicontseron_ [l=es] {_httpimg_/es/tseron.gif}
_widthtserx_ [l=es] {87}

## "fechas" ## nav_bar_button ## tdate ##
_httpicontdategr_ [l=es] {_httpimg_/es/tdategr.gif}
_httpicontdateof_ [l=es] {_httpimg_/es/tdateof.gif}
_httpicontdateon_ [l=es] {_httpimg_/es/tdateon.gif}
_widthtdatex_ [l=es] {87}

## "temas" ## nav_bar_button ## tsubj ##
_httpicontsubjgr_ [l=es] {_httpimg_/es/tsubjgr.gif}
_httpicontsubjon_ [l=es] {_httpimg_/es/tsubjon.gif}
_httpicontsubjof_ [l=es] {_httpimg_/es/tsubjof.gif}
_widthtsubjx_ [l=es] {87}

## "a" ## nav_bar_button ## tto ##
_httpiconttogr_ [l=es] {_httpimg_/es/ttogr.gif}
_httpiconttoon_ [l=es] {_httpimg_/es/ttoon.gif}
_httpiconttoof_ [l=es] {_httpimg_/es/ttoof.gif}
_widthttox_ [l=es] {87}

## "de" ## nav_bar_button ## tfrom ##
_httpicontfromgr_ [l=es] {_httpimg_/es/tfromgr.gif}
_httpicontfromon_ [l=es] {_httpimg_/es/tfromon.gif}
_httpicontfromof_ [l=es] {_httpimg_/es/tfromof.gif}
_widthtfromx_ [l=es] {87}

## "organizaciones" ## nav_bar_button ## torg ##
_httpicontorggr_ [l=es] {_httpimg_/es/torggr.gif}
_httpicontorgon_ [l=es] {_httpimg_/es/torgon.gif}
_httpicontorgof_ [l=es] {_httpimg_/es/torgof.gif}
_widthtorgx_ [l=es] {108}

## "c&oacute;mo" ## nav_bar_button ## thow ##
_httpiconthowgr_ [l=es] {_httpimg_/es/thowgr.gif}
_httpiconthowon_ [l=es] {_httpimg_/es/thowon.gif}
_httpiconthowof_ [l=es] {_httpimg_/es/thowof.gif}
_widththowx_ [l=es] {87}

## "temas" ## nav_bar_button ## ttopic ##
_httpiconttopicgr_ [l=es] {_httpimg_/es/ttopicgr.gif}
_httpiconttopicon_ [l=es] {_httpimg_/es/ttopicon.gif}
_httpiconttopicof_ [l=es] {_httpimg_/es/ttopicof.gif}
_widthttopicx_ [l=es] {87}

## "navegar" ## nav_bar_button ## tbrwse ##
_httpicontbrwsegr_ [l=es] {_httpimg_/es/tbrwsegr.gif}
_httpicontbrwseon_ [l=es] {_httpimg_/es/tbrwseon.gif}
_httpicontbrwseof_ [l=es] {_httpimg_/es/tbrwseof.gif}
_widthtbrwsex_ [l=es] {87}

## "navegar-meta" ## nav_bar_button ## tbrwse like above ##
_httpicontbrowsgr_ [l=es] {_httpimg_/es/tbrwsegr.gif}
_httpicontbrowson_ [l=es] {_httpimg_/es/tbrwseon.gif}
_httpicontbrowsof_ [l=es] {_httpimg_/es/tbrwseof.gif}
_widthtbrowsx_ [l=es] {87}

## "buscar" ## nav_bar_button ## tsrch ##
_httpicontsrchgr_ [l=es] {_httpimg_/es/tsrchgr.gif}
_httpicontsrchof_ [l=es] {_httpimg_/es/tsrchof.gif}
_httpicontsrchon_ [l=es] {_httpimg_/es/tsrchon.gif}
_widthtsrchx_ [l=es] {87}

## "t&iacute;tulos a-z" ## nav_bar_button ## ttitl ##
_httpiconttitlgr_ [l=es] {_httpimg_/es/ttitlgr.gif}
_httpiconttitlof_ [l=es] {_httpimg_/es/ttitlof.gif}
_httpiconttitlon_ [l=es] {_httpimg_/es/ttitlon.gif}
_widthttitlx_ [l=es] {90}

## "personas" ## nav_bar_button ## tpeop ##
_httpicontpeopgr_ [l=es] {_httpimg_/es/tpeopgr.gif}
_httpicontpeopof_ [l=es] {_httpimg_/es/tpeopof.gif}
_httpicontpeopon_ [l=es] {_httpimg_/es/tpeopon.gif}
_widthtpeopx_ [l=es] {87}

## "lengua" ## nav_bar_button ## tlang ##
_httpicontlanggr_ [l=es] {_httpimg_/es/tlanggr.gif}
_httpicontlangon_ [l=es] {_httpimg_/es/tlangon.gif}
_httpicontlangof_ [l=es] {_httpimg_/es/tlangof.gif}
_widthtlangx_ [l=es] {87}

## "sigla" ## nav_bar_button ## tacro ##
_httpicontacrogr_ [l=es] {_httpimg_/es/tacrogr.gif}
_httpicontacroof_ [l=es] {_httpimg_/es/tacroof.gif}
_httpicontacroon_ [l=es] {_httpimg_/es/tacroon.gif}
_widthtacrox_ [l=es] {87}

## "frases" ## nav_bar_button ## tphrse ##
_httpicontphrsegr_ [l=es] {_httpimg_/es/tphrsegr.gif}
_httpicontphrseof_ [l=es] {_httpimg_/es/tphrseof.gif}
_httpicontphrseon_ [l=es] {_httpimg_/es/tphrseon.gif}
_widthtphrsex_ [l=es] {87}

## "artistas" ## nav_bar_button ## tartst ##
_httpicontartstgr_ [l=es] {_httpimg_/es/tartstgr.gif}
_httpicontartstof_ [l=es] {_httpimg_/es/tartstof.gif}
_httpicontartston_ [l=es] {_httpimg_/es/tartston.gif}
_widthtartstx_ [l=es] {87}

## "nombres de ficheros" ## nav_bar_button ## tsrc ##
_httpicontsrcgr_ [l=es] {_httpimg_/es/tsrcgr.gif}
_httpicontsrcof_ [l=es] {_httpimg_/es/tsrcof.gif}
_httpicontsrcon_ [l=es] {_httpimg_/es/tsrcon.gif}
_widthtsrcx_ [l=es] {87}

## "palabras clave" ## nav_bar_button ## tkw ##
_httpicontkwgr_ [l=es] {_httpimg_/es/tkwgr.gif}
_httpicontkwof_ [l=es] {_httpimg_/es/tkwof.gif}
_httpicontkwon_ [l=es] {_httpimg_/es/tkwon.gif}
_widthtkwx_ [l=es] {87}

######################################################################
# 'about' page
package about
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textabcol_ [l=es] {Acerca de esta colección}

_textsubcols1_ [l=es] {<p>La colección completa comprende _1_ subcolecciones: 
<blockquote>} 

_textsubcols2_ [l=es] {</blockquote>
En la página de Preferencias puede usted seleccionar (y cambiar) las
subcolecciones que está utilizando actualmente.}

#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "acerca de" ## green_title ## h_about ##
_httpiconhabout_ [l=es] {_httpimg_/es/h\_about.gif}
_widthhabout_ [l=es] {200}
_heighthabout_ [l=es] {57}



######################################################################
# document package
package document
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_texticonhtitle_ [l=es] {Títulos A-Z}
_texticonhauth_ [l=es] {Autores A-Z}
_texticonhsubj_ [l=es] {Temas}
_texticonhto_ [l=es] {A}
_texticonhfrom_ [l=es] {De}
_texticonhser_ [l=es] {Series}
_texticonhdate_ [l=es] {Fechas}
_texticonhhow_ [l=es] {Cómo}
_texticonhorg_ [l=es] {Organizaciones}
_texticonhbrwse_ [l=es] {Navegar}
_texticonhbrows_ [l=es] {Navegar}
_texticonhpeople_ [l=es] {Personas A-Z}
_texticonhlanguage_ [l=es] {Lenguas}
_texticonhacronym_ [l=es] {Siglas}
_texticonhphrases_ [l=es] {Frases}
_texticonhartist_ [l=es] {Artistas}
_texticonhsrc_ [l=es] {Nombres de ficheros}
_texticonhkw_ [l=es] {Palabras clave}

_texticonopenbookshelf_ [l=es] {cerrar esta sección de la biblioteca}
_texticonclosedbookshelf_ [l=es] {abrir esta sección de la biblioteca y ver su contenido}
_texticonopenbook_ [l=es] {cerrar este libro}
_texticonclosedfolder_ [l=es] {Abrir esta carpeta y ver su contenido}
_texticonclosedfolder2_ [l=es] {abrir subsección: }
_texticonopenfolder_ [l=es] {cerrar esta carpeta}
_texticonopenfolder2_ [l=es] {cerrar subsección: }
_texticonsmalltext_ [l=es] {Ver esta sección del texto}
_texticonsmalltext2_ [l=es] {ver texto: }
_texticonpointer_ [l=es] {sección en curso}
_texticondetach_ [l=es] {Abrir esta página en una nueva ventana}
_texticonhighlight_ [l=es] {Resaltar los términos de la búsqueda}
_texticonnohighlight_ [l=es] {No resaltar los términos de la búsqueda}
_texticoncontracttoc_ [l=es] {Contraer el índice de contenido}
_texticonexpandtoc_ [l=es] {Expandir el índice de contenido}
_texticonexpandtext_ [l=es] {Mostrar el texto completo}
_texticoncontracttext_ [l=es] {Mostrar únicamente el texto de la sección seleccionada}
_texticonwarning_ [l=es] {<b>Advertencia: </b>}
_texticoncont_ [l=es] {¿desea continuar?}

_textltwarning_ [l=es] {
<p><center>
<table cellspacing=0 cellpadding=0 width=_pagewidth_>
<tr valign=top><td>_iconwarning_Expandir el texto aquí generará una gran
cantidad de datos que su navegador deberá procesar _imagecont_
</td></tr></table></center>
}  

_textgoto_ [l=es] {ir a la página}
_textintro_ [l=es] { <i>(texto inicial)</i>}

#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "t&iacute;tulos a-z" ## green_title ## h_title ##
_httpiconhtitle_ [l=es] {_httpimg_/es/h\_title.gif}
_widthhtitle_ [l=es] {200}
_heighthtitle_ [l=es] {57}

## "autores a-z" ## green_title ## h_auth ##
_httpiconhauth_ [l=es] {_httpimg_/es/h\_auth.gif}
_widthhauth_ [l=es] {200}
_heighthauth_ [l=es] {57}

## "temas" ## green_title ## h_subj ##
_httpiconhsubj_ [l=es] {_httpimg_/es/h\_subj.gif}
_widthhsubj_ [l=es] {200}
_heighthsubj_ [l=es] {57}

## "a" ## green_title ## h_to ##
_httpiconhto_ [l=es] {_httpimg_/es/h\_to.gif}
_widthhto_ [l=es] { 200}
_heighthto_ [l=es] { 57}

## "de" ## green_title ## h_from ##
_httpiconhfrom_ [l=es] {_httpimg_/es/h\_from.gif}
_widthhfrom_ [l=es] { 200}
_heighthfrom_ [l=es] { 57}

## "series" ## green_title ## h_ser ##
_httpiconhser_ [l=es] {_httpimg_/es/h\_ser.gif}
_widthhser_ [l=es] {200}
_heighthser_ [l=es] {57}

## "fechas" ## green_title ## h_date ##
_httpiconhdate_ [l=es] {_httpimg_/es/h\_date.gif}
_widthhdate_ [l=es] {200}
_heighthdate_ [l=es] {57}

## "c&oacute;mo" ## green_title ## h_how ##
_httpiconhhow_ [l=es] {_httpimg_/es/h\_how.gif}
_widthhhow_ [l=es] {200}
_heighthhow_ [l=es] {57}

## "temas" ## green_title ## h_topic ##
_httpiconhtopic_ [l=es] {_httpimg_/es/h\_topic.gif}
_widthhtopic_ [l=es] {200}
_heighthtopic_ [l=es] {57}

## "organizaci&oacute;n" ## green_title ## h_org ##
_httpiconhorg_ [l=es] {_httpimg_/es/h\_org.gif}
_widthhorg_ [l=es] {250}
_heighthorg_ [l=es] {57}

## "navegar" ## green_title ## h_brwse ##
_httpiconhbrwse_ [l=es] {_httpimg_/es/h\_brwse.gif}
_widthhbrwse_ [l=es] {200}
_heighthbrwse_ [l=es] {57}

## "navegar-meta" ## green_title ## h_brwse like above ##
_httpiconhbrows_ [l=es] {_httpimg_/es/h\_brwse.gif}
_widthhbrows_ [l=es] { 200}
_heighthbrows_ [l=es] { 57}

## "personas" ## green_title ## h_people ##
_httpiconhpeople_ [l=es] {_httpimg_/es/h\_people.gif}
_widthhpeople_ [l=es] {200}
_heighthpeople_ [l=es] {57}

## "lenguas" ## green_title ## h_lang ##
_httpiconhlanguage_ [l=es] {_httpimg_/es/h\_lang.gif}
_widthhlanguage_ [l=es] {200}
_heighthlanguage_ [l=es] {57}

## "siglas" ## green_title ## h_acro ##
_httpiconhacronym_ [l=es] {_httpimg_/es/h\_acro.gif}
_widthhacronym_ [l=es] {200}
_heighthacronym_ [l=es] {57}

## "frases" ## green_title ## h_phrse ##
_httpiconhphrse_ [l=es] {_httpimg_/es/h\_phrse.gif}
_widthhphrse_ [l=es] {200}
_heighthphrse_ [l=es] {57}

## "artistas" ## green_title ## h_artist ##
_httpiconhartist_ [l=es] {_httpimg_/es/h\_artist.gif}
_widthhartist_ [l=es] {200}
_heighthartist_ [l=es] {57}

## "nombres de ficheros" ## green_title ## h_src ##
_httpiconhsrc_ [l=es] {_httpimg_/es/h\_src.gif}
_widthhsrc_ [l=es] {200}
_heighthsrc_ [l=es] {57}

## "palabras clave" ## green_title ## h_kw ##
_httpiconhkw_ [l=es] {_httpimg_/es/h\_kw.gif}
_widthhkw_ [l=es] {200}
_heighthkw_ [l=es] {57}

## "¿DESEA CONTINUAR?" ## top_nav_button ## cont ##
_httpiconcontoff_ [l=es] {_httpimg_/es/contof.gif}
_httpiconconton_ [l=es] {_httpimg_/es/conton.gif}

## "    TEXTO 
COMPLETO" ## document_button ## eallt ## 
_httpiconealltof_ [l=es] {_httpimg_/es/ealltof.gif}
_httpiconeallton_ [l=es] {_httpimg_/es/eallton.gif}

## " CONTRAER 
    &Iacute;NDICE" ## document_button ## econc ##
_httpiconeconcof_ [l=es] {_httpimg_/es/econcof.gif}
_httpiconeconcon_ [l=es] {_httpimg_/es/econcon.gif}

## "SEPARAR" ## document_button ## edtch ##
_httpiconedtchof_ [l=es] {_httpimg_/es/edtchof.gif}
_httpiconedtchon_ [l=es] {_httpimg_/es/edtchon.gif}

## "EXPANDIR 
   &Iacute;NDICE" ## document_button ## eexpc ##
_httpiconeexpcof_ [l=es] {_httpimg_/es/eexpcof.gif}
_httpiconeexpcon_ [l=es] {_httpimg_/es/eexpcon.gif}

## "CONTRAER 
    TEXTO" ## document_button ## etsec ##
_httpiconetsecof_ [l=es] {_httpimg_/es/etsecof.gif}
_httpiconetsecon_ [l=es] {_httpimg_/es/etsecon.gif}

## "RESALTAR" ## document_button ## ehl ##
_httpiconehlof_ [l=es] {_httpimg_/es/ehlof.gif}
_httpiconehlon_ [l=es] {_httpimg_/es/ehlon.gif}

## "     NO 
RESALTAR" ## document_button ## enhl ##
_httpiconenhlof_ [l=es] {_httpimg_/es/enhlof.gif}
_httpiconenhlon_ [l=es] {_httpimg_/es/enhlon.gif}


######################################################################
# 'search' page
package query
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

# this if statement produces the text 'results n1 - nn for query: querystring' or 
# 'No matches for query: querystring', depending on whether or not there were
# any matches
_textquerytitle_ [l=es] {_If_(_thislast_,resultados _thisfirst_ - _thislast_ para la consulta:_cgiargq_,No se encontraron resultados correspondientes a  la consulta: _cgiargq_)}

_textnoquerytitle_ [l=es] {Página de búsqueda}

_texticonthispage_ [l=es] {buscar}
_textsome_ [l=es] {_If_(_cgiargb_,clasificado,algunos)}
_textall_ [l=es] {_If_(_cgiargb_,booleano,todos)}
_textformsome_ [l=es] {_If_(_cgiargb_,ranked,algunos)}
_textformall_ [l=es] {_If_(_cgiargb_,natural,todos)}
_texticonqueryresultsbar_ [l=es] {}
_texticonsearchhistorybar_ [l=es] {historial de búsquedas}

#alt text for query buttons
_textusequery_ [l=es] {utilizar esta consulta}
_textfreqmsg1_ [l=es] {Palabras contadas: }
_textpostprocess_ [l=es] {_If_(_quotedquery_,<br><i>postprocesado para encontrar _quotedquery_</i>
)}					     

_textmorethan_ [l=es] {Más de }
_textapprox_ [l=es] {Acerca de }
_textnodocs_ [l=es] {No hay documentos que correspondan a la consulta.}
_text1doc_ [l=es] {1 documento corresponde a la consulta.}
_textlotsdocs_ [l=es] {documentos corresponden a la consulta.}
_textmatches_ [l=es] {Resultados }
_textbeginsearch_ [l=es] {Iniciar la búsqueda}
_textrunquery_ [l=es] {Ejecutar la búsqueda}
_textclearform_ [l=es] {Borrar el formulario}

#these go together in form search:
#"Word or phrase  (fold, stem)  ... in field"
_textwordphrase_ [l=es] {Palabra o frase}
_textinfield_ [l=es] {... en el campo}
_textfoldstem_ [l=es] {(mayúsculas y minúsculas, terminaciones de palabras)}

_textadvquery_ [l=es] {O teclee directamente una consulta:}
_textallfields_ [l=es] {Todos los campos}
_textand_ [l=es] {y}
_textor_ [l=es] {o}
_textandnot_ [l=es] {y no}

# _hselection_, _jselection_, _nselection_ and _gselection_ are set from 
# within the server some or all of them may remain unset

_textsimplesearch_ [l=es] {Buscar _If_(_hselection_, _hselection_)_If_(_jselection_,_textjselect_)_If_(_nselection_, en idioma _nselection_) 
que contengan _querytypeselection_ las palabras}

_textadvancedsearch_ [l=es] {Buscar _If_(_hselection_, _hselection_, _defaultindextext_)_If_(_jselection_,_textjselect_)_If_(_nselection_, en idioma _nselection_) 
utilizando la consulta _querytypeselection_}

_textformsimplesearch_ [l=es] {Buscar_If_(_hselection_, _hselection_)
_If_(_jselection_, _textjselect_) _If_(_gselection_, at _gselection_
level) _If_(_nselection_, in _nselection_ language) que contengan
_formquerytypeselection_ de}

_textformadvancedsearch_ [l=es] {Buscar _If_(_hselection_, _hselection_,
_defaultindextext_) _If_(_jselection_,_textjselect_) _If_(_gselection_,
at _gselection_ level)_If_(_nselection_, in _nselection_ language) y
 presentar los resultados por orden _formquerytypeselection_ }

_textjselect_ [l=es] {_If_(_hselection_, de) _jselection_}

_textdatesearch_ [l=es] { <p>Se pueden buscar en esta colección
documentos comprendidos en un intervalo de fechas, o documentos que
contengan una fecha en particular. Ésta es una característica
facultativa de la búsqueda.}
_textstartdate_ [l=es] {Fecha inicial (o única):}
_textenddate_ [l=es] {Fecha final:}
_textbc_ [l=es] {antes de nuestra era}
_textad_ [l=es] {de nuestra era}
_textexplaineras_ [l=es] {«de nuestra era» y «antes de nuestra era» son
formas alternativas de expresar «después de Jesucristo» y «antes de
Jesucristo», respectivamente. Son expresiones con menos connotaciones
culturales.} 

_textstemon_ [l=es] { (ignorar las terminaciones de las palabras)}

_textsearchhistory_ [l=es] {historial de búsquedas}

#text macros for search history
_textnohistory_ [l=es] {No está disponible el historial de búsquedas}
_texthresult_ [l=es] {resultado}
_texthresults_ [l=es] {resultados}
_texthallwords_ [l=es] {todas las palabras}
_texthsomewords_ [l=es] {algunas palabras}
_texthboolean_ [l=es] {booleano}
_texthranked_ [l=es] {clasificado}
_texthcaseon_ [l=es] {tener en cuenta mayúsculas y minúsculas}
_texthcaseoff_ [l=es] {no tener en cuenta mayúsculas y minúsculas}
_texthstemon_ [l=es] {no tener en cuenta las terminaciones de las palabras}
_texthstemoff_ [l=es] {tener en cuenta las terminaciones de las palabras}

#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "buscar" ## green_title ## h_search ##
_httpiconhsearch_ [l=es] {_httpimg_/es/h\_search.gif}
_widthhsearch_ [l=es] {200}
_heighthsearch_ [l=es] {57}

## "resultados" ## green_bar_left_aligned ## qryresb ##
_httpiconqryresb_ [l=es] {_httpimg_/es/qryresb.gif}
_widthqryresb_ [l=es] {_pagewidth_}
_heightqryresb_ [l=es] {17}

## "historial" ## green_bar_left_aligned ## schhistb ##
_httpiconsrchhistb_ [l=es] {_httpimg_/es/schhistb.gif}
_widthsrchhistb_ [l=es] {_pagewidth_}
_heightsrchhistb_ [l=es] {17}

## "mostrar" ## hand_made ##
_httpicondisplay_ [l=es] {_httpimg_/es/display.gif}
_widthdisplay_ [l=es] {60}
_heightdisplay_ [l=es] {20}

######################################################################
# 'preferences' page
package preferences
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textprefschanged_  [l=es] {

Las preferencias se han fijado de la siguiente manera. ¡No pulse el
botón «Atrás» de su navegador, pues eso haría que no quedaran grabadas!
Utilice más bien uno de los botones de la barra de acceso que aparece
más arriba.

}
_textsetprefs_  [l=es] {fijar preferencias}
_textsearchprefs_ [l=es] {Preferencias de búsqueda}
_textcollectionprefs_ [l=es] {Preferencias de colección}
_textpresentationprefs_ [l=es] {Preferencias de presentación}
_textpreferences_ [l=es] {Preferencias}
_textcasediffs_ [l=es] {Reconocimiento de mayúsculas y minúsculas:}
_textignorecase_ [l=es] { ignorar diferencias entre mayúsculas y minúsculas}
_textmatchcase_ [l=es] { deben corresponder mayúsculas y minúsculas}
_textwordends_ [l=es] {Terminaciones de las palabras:}
_textstem_ [l=es] { ignorar las terminaciones de las palabras}
_textnostem_ [l=es] { debe corresponder la palabra completa}
_textprefop_ [l=es] {Presentar hasta _maxdocoption_ resultados con _hitsperpageoption_ resultados por página.}
_textextlink_ [l=es] {Acceder a páginas Web externas: }
_textintlink_ [l=es] {Documentos fuente recuperados de:}
_textlanguage_ [l=es] {Idioma de la interfaz: }
_textencoding_ [l=es] {Codificación: }
_textformat_ [l=es] {Formato de la interfaz: }
_textall_ [l=es] {todos}
_textquerymode_ [l=es] {Tipo de búsqueda:}
_textsimplemode_ [l=es] {búsqueda simple}
_textadvancedmode_ [l=es] {búsqueda avanzada (permite efectuar búsquedas booleanas utilizando los caracteres !, &amp;, | y los paréntesis)}
_textlinkinterm_ [l=es] {a través de una página intermedia}
_textlinkdirect_ [l=es] {ir directamente ahí}
_textdigitlib_ [l=es] {la biblioteca electrónica}
_textweb_ [l=es] {la red mundial (web)}
_textgraphical_ [l=es] {Gráfico}
_texttextual_ [l=es] {Textual}
_textcollectionoption_ [l=es] {<p>
Subcolecciones por incluir:
<br>}

_textrelateddocdisplay_ [l=es] { mostrar documentos conexos }
_textsearchhistory_ [l=es] { historial de búsquedas:}
_textnohistory_ [l=es] { el historial de búsquedas no está disponible }
_texthistorydisplay_ [l=es] { mostrar _historynumrecords_ historial de las últimas búsquedas}
_textnohistorydisplay_ [l=es] { no mostrar el historial de búsquedas }

_texttypesearch_ [l=es] { Tipo de búsqueda:}
_texttextsearch_ [l=es] { búsqueda textual}
_textformsearch_ [l=es] { búsqueda de formulario}
_textqueryboxsize_ [l=es] { Tamaño del cuadro de búsqueda:}
_textregbox_ [l=es] { cuadro de búsqueda normal}
_textbigbox_ [l=es] { cuadro de búsqueda grande}
_textformtype_ [l=es] {Tipo de formulario:}
_textsimple_ [l=es] { simple}
_textadvanced_ [l=es] { avanzado}

# used in "with 4 fields" in the form search box
_textwith_ [l=es] {con}
_textfields_ [l=es] {campos}


#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "preferencias" ## green_title ## h_pref ##
_httpiconhpref_ [l=es] {_httpimg_/es/h\_pref.gif}
_widthhpref_ [l=es] {200}
_heighthpref_ [l=es] {57}

#####################################################################
# 'browse' package for the dynamic browsing interface
package browse
#####################################################################

_textsortby_ [l=es] {Ordenar los documentos por}
_textalsoshowing_ [l=es] {muestra también}
_textwith_ [l=es] {con un máximo de} 
_textdocsperpage_ [l=es] {documentos por página}

_textfilterby_ [l=es] {Buscar documentos que contengan}
_textall_ [l=es] {todos}
_textany_ [l=es] {algunos de los}
_textwords_ [l=es] {las palabras}
_textleaveblank_ [l=es] {dejar este cuadro vacío para obtener todos los documentos}

_browsebuttontext_ [l=es] {"Ordenar los documentos"}

_nodata_ [l=es] {<i>no datos</i>}
_docs_ [l=es] {documentos}

######################################################################
# 'help' page -- this is lower priority for translating than the
# rest of this file
package help
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textHelp_ [l=es] {Ayuda}
_textSearchshort_ [l=es] {Buscar determinadas palabras}
_textSeriesshort_ [l=es] {Acceder a las publicaciones por series}
_textDateshort_ [l=es] {Acceder a las publicaciones por fecha}
_textSubjectshort_ [l=es] {Acceder a las publicaciones por tema}
_textToshort_ [l=es] {Acceder a las publicaciones por campo «A»}
_textFromshort_ [l=es] {Acceder a las publicaciones por campo «De»}
_textTitleshort_ [l=es] {Acceder a las publicaciones por título}
_textBrowseshort_ [l=es] {Navegar en las publicaciones}
_textCreatorshort_ [l=es] {Acceder a las publicaciones por autor}
_textOrganizationshort_ [l=es] {Acceder a las publicaciones por organización}
_textHowtoshort_ [l=es] {Acceder a las publicaciones por lista de "cómo"}
_textTopicshort_ [l=es] {Acceder a las publicaciones por tema}
_textPeopleshort_ [l=es] {Acceder a las publicaciones por personas}
_textLanguageshort_ [l=es] {Acceder a las publicaciones por lengua}
_textAcronymshort_ [l=es] {Acceder a las publicaciones por aparición de siglas}
_textPhraseshort_ [l=es] {Navegar en las frases que aparecen en las publicaciones}
_textArtistshort_ [l=es] {Acceder a las publicaciones por artista}
_textSourceshort_ [l=es] {Acceder a las publicaciones por nombre de fichero}
_textKeywordshort_ [l=es] {Acceder a las publicaciones por palabra clave}
_textdefaultshorttext_ [l=es] {Clasificación no definida}

_textSearchlong_ [l=es] { <p>Se puede <i>buscar determinadas
palabras</i> que aparecen en el texto desde la página de "búsqueda". Ésta
es la primera página que aparece al principio y a la que se puede
acceder desde otras páginas pulsando el botón <i>buscar</i>. }

_textTitlelong_ [l=es] { <p>Se puede <i>acceder a las publicaciones por
título</i> pulsando el botón <i>títulos a-z</i>. El resultado será una
lista de libros por orden alfabético. }

_textOrganizationlong_ [l=es] { <p>Se puede <i>acceder a las publicaciones
por organización</i> pulsando el botón <i>organización</i>. El resultado
será una lista de organizaciones. }

_textHowtolong_ [l=es] { <p>Se puede <i>acceder a las publicaciones por una
lista de "cómo"</i> pulsando el botón <i>cómo</i>.
El resultado será una lista de rúbricas "cómo". }

_textCreatorlong_ [l=es] { <p>Se puede <i>acceder a publicaciones por
autor</i> pulsando el botón <i>autores a-z</i>. El resultado será una
lista de libros ordenados por nombre del autor. }

_textTopiclong_ [l=es] { <p>Se puede <i>acceder a las publicaciones por
tema</i> pulsando el botón <i>tema</i>. El resultado será una lista de
temas. }

_textSubjectlong_ [l=es] { <p>Se puede <i>acceder a las publicaciones
por tema</i> presionando el botón de <i>temas</i>. El resultado será una
lista de temas, representados por libreros. }

_textTolong_ [l=es] { <p>Se puede <i>acceder a las publicaciones por
campo «A»</i> pulsando el botón <i>a</i>. El resultado será una lista de
destinatarios. }

_textFromlong_ [l=es] { <p>Se puede <i>acceder a las publicaciones por
campo «De»</i> pulsando el botón <i>de</i>. El resultado será una lista
de remitentes. }

_textSerieslong_ [l=es] { <p>Se puede <i>acceder a las publicaciones por
series</i> pulsando el botón <i>series</i>. El resultado será una lista
de las series que se encuentran en la colección. }

_textDatelong_ [l=es] { <p>Se puede <i>acceder a las publicaciones por
fecha</i> pulsando el botón <i>fechas</i>. El resultado será una lista
de todas las publicaciones, ordenadas cronológicamente. }

_textBrowselong_ [l=es] { <p>Se puede <i>navegar en las publicaciones</i>
pulsando el botón <i>navegar</i>. }

_textPeoplelong_ [l=es] { <p>Se puede <i>acceder a las publicaciones por
personas</i> pulsando el botón <i>personas a-z</i>. El resultado será una
lista ordenada por apellido. }

_textLanguagelong_ [l=es] { <p>Se puede <i>acceder a las publicaciones por
lengua</i> presionando el botón <i>lenguas</i>. El resultado será una
lista ordenada por lengua. }

_textAcronymlong_ [l=es] { <p>Se puede <i>acceder a las publicaciones por
aparición de siglas</i> pulsando el botón <i>siglas</i>. El resultado
será una lista de siglas y los lugares donde aparecen. }

_textPhraselong_ [l=es] { <p>Se puede <i>navegar en las frases que aparecen
en las publicaciones</i> pulsando el botón <i>frases</i>. Para ello se
utiliza el navegador "phind phrase". }

_textArtistlong_ [l=es] { <p>Se puede <i>acceder a las publicaciones por
artista</i> pulsando el botón <i>artistas</i>. El resultado será una
lista ordenada por nombre de artista. }

_textSourcelong_ [l=es] { <p>Se puede <i>acceder a las publicaciones por
nombre de fichero</i> pulsando el botón <i>nombres de ficheros</i>. El
resultado será una lista ordenada por nombre de fichero original. }

_textKeywordlong_ [l=es] { <p>Se puede <i>acceder a las publicaciones por
palabra clave</i> pulsando el botón <i>palabras clave</i>. El resultado
será una lista de palabras clave. }

_textdefaultlongtext_ [l=es] { <p>Pulse el botón <i>desconocido</i> para
consultar las publicaciones (la lista se ordena según un campo
desconocido). }

_texthelptopics_ [l=es] {

<h2 align=left>Temas</h2>
<ul>
  <li><a href="\#finding-information">_textsimplehelpheading_</a>
  _topicreadingdocs_
  <li><a href="\#searching">¿Cómo buscar determinadas palabras?</a>
<ul>
  <li><a href="\#query-terms">Términos de la búsqueda</a>
  <li><a href="\#query-type">Tipo de consulta</a>
  <li><a href="\#scope-of-queries">Campo de acción de las búsquedas</a>
</ul>
  <li><a href="\#preferences">_textchangeprefs_</a>
<ul>
  <li><a href="\#col-prefs">Preferencias de colección</a>
  <li><a href="\#lang-prefs">Preferencias de lengua</a>
  <li><a href="\#pres-prefs">Preferencias de presentación</a>
  <li><a href="\#search-prefs">Preferencias de búsqueda</a>
</ul>
</ul>
}

# there are 4 versions of this section of the help text.
# which version is used is currently set within the server
# (it should probably use the macro language e.g. [type=book])
# 1 = html (like fao collections) -- section is empty
# 2 = book (like hdl collection) -- macros beginning with book
# 3 = bibliographic (like csbib) -- macros beginning with bib
# 4 = standard (like gberg) -- the default

_topicreadingdocs_ [l=es] {<li><a href="\#reading-docs">_textreadingdocs_</a>}

_textreadingdocs_ [l=es] {¿Cómo leer los documentos?}
_booktextreadingdocs_ [l=es] {¿Cómo leer los libros?}
_bibtextreadingdocs_ [l=es] {Obtener más información sobre un elemento bibliográfico}

_texthelpreadingdocs_ [l=es] {
<p>_iconblankbar_
<a name=reading-docs>
<h2>_textreadingdocs_</h2>

<p>Cuando aparece en pantalla un documento en particular, su título y su
autor se pueden ver en la parte superior izquierda de la página. Al lado
de éstos, se puede ver el número de la página en curso, un cuadro que
permite seleccionar una nueva página y las flechas que permiten pasar a
la página siguiente o la anterior.

<p>Más abajo aparece el texto de la sección en curso. Al final de la
lectura, se pueden utilizar las flechas que se encuentran en la parte
inferior para pasar a la sección siguiente o regresar a la anterior.

<p>Debajo del título y el autor hay tres botones. Pulse <i>texto
completo</i> para abrir el texto completo del documento en curso. ¡Si el
documento es voluminoso, esta operación puede tardar mucho tiempo y
utilizar mucha memoria! Pulse <i>separar</i> para crear un nueva ventana
en su navegador para este documento (esto es útil si se desea comparar
documentos o leer dos a la vez). Por último, cuando se efectúa una
búsqueda, las palabras buscadas aparecen resaltadas; pulse <i>sin
resaltar</i> para eliminar esta apariencia.

<p>
<table cellspacing="0" cellpadding="2" border="0">
<tr><td colspan=2><img src="_httpiconmore_" border="0"></td><td>Pulse la flecha para ir a la sección siguiente ...</td></tr>
<tr><td colspan=2><img src="_httpiconless_" border="0"></td><td>...o regresar a la sección anterior</td></tr>
<tr><td><img src="_document:httpiconealltof_" border="0"></td><td><img 
src="_document:httpiconetsecof_" border="0"></td><td>Abrir o no el texto completo</td></tr>
<tr><td colspan=2><img src="_document:httpiconedtchof_" border="0"></td><td>Abrir esta página en una nueva ventana</td></tr>
<tr><td><img src="_document:httpiconehlof_" border="0"></td><td><img
src="_document:httpiconenhlof_" border="0"></td><td>Resaltar o no los términos buscados</td></tr>
</table>

}

_booktexthelpreadingdocs_ [l=es] {
<p>_iconblankbar_
<a name=reading-docs>
<h2>_textreadingdocs_</h2>

<p>Cuando se llega a un libro en particular, la fotografía de su portada
aparece en la parte superior izquierda de la página. Al lado de la
fotografía figura el índice de contenido con una flecha que indica dónde
se encuentra usted. Este índice es expandible: pulse las carpetas para
abrirlas o cerrarlas. Pulse el libro abierto, que se encuentra en la
parte superior, para cerrarlo.

<p>Debajo aparece el texto de la sección en curso. Cuando lo haya leído,
puede utilizar las flechas que se encuentran en la parte inferior para
pasar a la sección siguiente o regresar a la sección anterior.

<p>Debajo de la fotografía hay cuatro botones. Pulse el botón <i>texto
completo</i> para desplegar el texto completo de la sección o del libro
en curso. ¡Si el libro es voluminoso, esta operación puede tardar mucho
tiempo y utilizar mucha memoria! Pulse <i>expandir índice</i> para
expandir el índice completo y así poder ver todos los títulos de
capítulos y subsecciones. Pulse <i>separar</i> para abrir una nueva
ventana de su navegador para este documento (esto es útil si se desea
comparar libros o leer dos a la vez). Por último, al efectuar una
búsqueda, las palabras buscadas aparecen resaltadas; pulse <i>sin
resaltar</i> para eliminar esta apariencia.

<p>
<table cellspacing="0" cellpadding="2" border="0">
<tr><td colspan=2><img src="_httpiconbshelf_" border="0"></td><td>Abrir este estante</td></tr>
<tr><td><img src="_httpiconopenbook_" border="0"></td><td><img 
src="_httpiconbook_" border="0"></td><td>Abrir/cerrar este libro</td></tr>
<tr><td colspan=2><img src="_httpiconitext_" border="0"></td><td>Ver esta sección del texto</td></tr>
<tr><td><img src="_document:httpiconealltof_" border="0"></td><td><img 
src="_document:httpiconetsecof_" border="0"></td><td>Desplegar o no el texto completo</td></tr>
<tr><td><img src="_document:httpiconeexpcof_" border="0"></td><td><img
src="_document:httpiconeconcof_" border="0"></td><td>Expandir o no el índice de contenido</td></tr>
<tr><td colspan=2><img src="_document:httpiconedtchof_" border="0"></td><td>Abrir esta página en una nueva ventana</td></tr>
<tr><td><img src="_document:httpiconehlof_" border="0"></td><td><img
src="_document:httpiconenhlof_" border="0"></td><td>Resaltar o no los términos de la búsqueda</td></tr>
<tr><td colspan=2><img src="_httpiconmore_" border="0"></td><td>Presionar la flecha para ir a la sección siguiente...</td></tr>
<tr><td colspan=2><img src="_httpiconless_" border="0"></td><td>...o regresar a la sección anterior</td></tr>
</table>
}

_bibtexthelpreadingdocs_ [l=es] {
<p>_iconblankbar_
<a name=reading-docs>
<h2>_textreadingdocs_</h2>

<p>Algunos elementos bibliográficos contienen más información, por
ejemplo un resumen. Se puede saber desde la página de resultados si este
es el caso porque éstos van acompañados del icono _icontext_ en lugar
del ícono _iconblanktext_.

<p>CPulsando el icono _icontext_ obtendrá más información acerca del
elemento bibliográfico correspondiente.

<p>Debajo del elemento bibliográfico hay dos botones. Pulse
<i>separar</i> para crear una nueva ventana de su navegador para este
libro (esto es útil si se desea comparar elementos bibliográficos). Por
último, al efectuar una búsqueda, las palabras buscadas aparecen
resaltadas; pulse <i>sin resaltar</i> para eliminar esta apariencia.

<p>
<table cellspacing="0" cellpadding="2" border="0">
<tr><td colspan=2><img src="_document:httpiconedtchof_" border="0"></td><td>Abrir esta página en una nueva ventana</td></tr>
<tr><td><img src="_document:httpiconehlof_" border="0"></td><td><img
src="_document:httpiconenhlof_" border="0"></td><td>Resaltar o no los términos buscados</td></tr>
</table>
}

_texthelpsearching_ [l=es] {
<h2>¿Cómo buscar determinadas palabras?</h2>

<p>Desde la página de búsqueda, se puede hacer una consulta siguiendo
estos pasos:

<ol>

<li>Especificar qué documentos quiere buscar

<li>Indicar si quiere buscar todas las palabras o sólo algunas

<li>Escribir las palabras que quiere buscar

<li>Pulsar el botón <i>Iniciar la búsqueda</i>

</ol> 

<p>Cuando se hace una consulta, aparecen los títulos de los veinte
primeros documentos correspondientes. Al final de la lista hay un botón
que permite acceder a los veinte documentos siguientes, y así
sucesivamente. Pulse el título de cualquier documento o el botoncito que
aparece al lado para verlo.

<p>El número máximo de documentos obtenidos es de 100. Puede cambiar
este número pulsando el botón <i>preferencias</i> que se encuentra en la
parte superior de la página.

<p>_iconblankbar_
<a name=query-terms>
<h3>Términos de la búsqueda</h3>

<p>Lo que se teclea en el cuadro de consulta se interpreta como una
lista de palabras llamadas "términos de la búsqueda". Cada término debe
contener solamente letras y dígitos. Los términos se separan por un
espacio en blanco. Si aparecen otros caracteres, como los de puntuación,
se interpretan como espacios para separar los términos y la búsqueda no
los tiene en cuenta. No se pueden efectuar búsquedas con palabras que
incluyan puntuación.

<p>Por ejemplo, la consulta:

<ul><kbd>Agro-forestry in the Pacific Islands: Systems for
Sustainability (1993)</kbd></ul>

<p>se tratará de igual manera que:

<ul><kbd>Agro forestry in the Pacific Islands Systems for Sustainability
1993</kbd></ul><p>
      
<p>_iconblankbar_
<a name=query-type>
<h3>Tipo de consulta</h3>

<p>Existen dos tipos de consulta.

<ul>

<li>Búsqueda de <b>todas</b> las palabras. Se buscan los documentos que
contienen todas las palabras especificadas. Los documentos que responden
a la consulta se presentan por orden alfabético.

<li>Búsqueda de <b>determinada(s)</b> palabra(s). Basta con enumerar los
términos que pueden aparecer en los documentos buscados. Los documentos
aparecerán en un orden que corresponde a su grado de pertinencia con
respecto a la consulta. Para determinar el grado de pertinencia, se
aplican los criterios siguientes:

<ul>

<li>cuantos más términos buscados contenga el documento, mayor será su
pertinencia;

<li>los términos poco usuales se considerarán más importantes que los
comunes;

<li>los documentos más cortos se considerarán más pertinentes que los
documentos más voluminosos.

</ul>

</ul>

<p>Puede utilizar tantos términos de búsqueda como desee: una oración
completa, o incluso un párrafo entero.  Si sólo se especifica un
término, los documentos se ordenarán por frecuencia de aparición del
término buscado.

<p>_texthelpscope_

}

_textdatesearch_ [l=es] {Buscar con fechas}

_texthelpdatesearch_ [l=es] {

<h2>_textdatesearch_</h2>

<p>La búsqueda por fecha permite encontrar documentos que, además de
corresponder a los criterios de búsqueda, se refieren a acontecimientos
situados en un intervalo de tiempo determinado. Se pueden buscar
documentos relativos a un año en particular o comprendidos en un
intervalo particular de años. Obsérvese que no es necesario proporcionar
términos de búsqueda - se puede buscar únicamente por la fecha. Tampoco
es preciso indicar fechas en la búsqueda: si no se indica ninguna fecha
es como si no existiera la búsqueda por fecha.

<p>_iconblankbar_
<a name=datesearch-howto>
<h3> Cómo utilizar esta función:</h3>

<ul> 

<li>Para buscar documentos referentes a un año en particular:

<ul>

<li>Teclear los términos de la búsqueda como de costumbre.

<li>Indicar el año deseado en el cuadro "Fecha inicial (o única)".

<li>Si la fecha es anterior a nuestra era (antes de Jesucristo), hay que
elegir la opción "antes de nuestra era" en el menú situado cerca de ese
cuadro.

<li>Iniciar la búsqueda como de costumbre.

</ul>

<li>Para buscar documentos referentes a un periodo o un intervalo de
años:

<ul>

<li>Teclear los términos de la búsqueda como de costumbre.

<li>Indicar el año inicial en el cuadro "Fecha inicial (o única)".

<li>Indicar el año final en el cuadro "Fecha final".

<li>Seleccionar la opción "antes de nuestra era" en el menú situado
cerca del cuadro donde se teclea la fecha anterior a nuestra era (antes
de Jesucristo).

<li>Iniciar la búsqueda como de costumbre.

</ul>

</ul>

<p>_iconblankbar_
<a name=datesearch-results>
<h3>Como interpretar los resultados de las búsquedas</h3>

<p>Por lo general, una búsqueda de documentos referentes al año 1903 no
permitirá obtener documentos que, por ejemplo, tratan de libros escritos
en 1903, sino sólo documentos referentes al año 1903.  Sin embargo, dada
la manera en que se buscan las fechas de los documentos, se obtendrán
documentos referentes a un intervalo de años (por ejemplo 1899-1911) que
comprende el año 1903, así como los documentos que citan en su texto el
siglo al que pertenece el año 1903 (por ejemplo el siglo XX, o el siglo
veinte).  Esto significa que, para algunos documentos, las fechas
indicadas en la búsqueda no aparecerán realmente en el texto del
documento. Para una búsqueda por intervalo de tiempo, todo lo anterior
se aplica a todas las fechas del intervalo.

}

_textchangeprefs_ [l=es] {Cambio de preferencias}

_texthelppreferences_ [l=es] {

<h2>_textchangeprefs_</h2>

<p>Si desea cambiar algunas características de la interfaz para
adaptarla a sus propias necesidades, pulse el botón <i>preferencias</i>,
situado en la parte superior de la página.

<p>_iconblankbar_
<a name=col-prefs>
<h3 align=left>Preferencias de colección</h3>
<p>
Algunas colecciones se componen de varias subcolecciones, en las cuales
se pueden efectuar operaciones de búsqueda de forma individual o en su
conjunto, como un todo. Si lo desea, puede usted seleccionar en la
página de <i>preferencias</i> qué subcolecciones incluir en sus
búsquedas.

<p>_iconblankbar_
<a name=lang-prefs>
<h3 align=left>Preferencias de lengua</h3>

<p>Cada colección tiene una lengua de presentación por defecto, pero si
lo desea puede usted cambiar de idioma. Puede usted modificar también el
sistema de codificación que utiliza su navegador: el programa Greenstone
suele escoger los parámetros por defecto, pero con algunos navegadores
se pueden conseguir mejores resultados gráficos cambiando de sistema de
codificación. En todas las colecciones se puede escoger entre una
interfaz gráfica normalizada y una interfaz textual. Ésta resulta
particularmente útil para los usuarios con problemas de vista que
utilizan tipos de letra grandes o para la salida a sintetizadores
vocales.

<p>_iconblankbar_
<a name=pres-prefs>
<h3 align=left>Preferencias de presentación</h3>

<p>Según la colección, se pueden especificar varias opciones que definen
la presentación.

<p>Las colecciones de páginas Web permiten eliminar la barra de
navegación de Greenstone que aparece en la parte superior de cada página
de un documento, de tal modo que una vez terminada la búsqueda se
visualiza directamente la página correspondiente sin los encabezados de
Greenstone. Para efectuar otra búsqueda tendrá que utilizar el botón
"Atrás" de su navegador. Estas colecciones le permiten también eliminar
el mensaje de advertencia de Greenstone que aparece cuando un
hiperenlace lo lleva a usted fuera de la colección de la biblioteca
electrónica y hacia otra parte en Internet. En algunas colecciones de
páginas Web, se puede determinar también si los enlaces que aparecen en
la página de "Resultados de la búsqueda" remitirán directamente al URL
en cuestión o más bien a la copia de la página que se encuentra en la
biblioteca electrónica.

<p>_iconblankbar_
<a name=search-prefs>
<h3 align=left>Preferencias de búsqueda</h3>

Dos pares de botones controlan la diferencia entre mayúsculas y
minúsculas y las raíces de las búsquedas que hace. El primer conjunto de
botones controla si deben coincidir mayúsculas o minúsculas. El segundo
conjunto controla si se ignoran o no las terminaciones de las palabras
(raíces).

<p>Por ejemplo, si se activan los botones <i>ignorar diferencias entre
mayúsculas y minúsculas</i> e <i>ignorar terminaciones de palabras</i>,
la búsqueda:

<p><ul><kbd>African building</kbd></ul>

<p>se tratará del mismo modo que:

<p><ul><kbd>africa builds</kbd></ul>

<p>porque la letra mayúscula de "African" se transformará en minúscula y
los sufijos "n" e "ing" se eliminaran de "African" y "building",
respectivamente (se suprimirá también la "s" de "builds").

<p>Se puede también optar por el modo de búsqueda "avanzado" que permite
combinar términos utilizando los operadores booleanos AND (&amp;), OR
(|), y NOT (!). Esto le permitirá efectuar búsquedas más precisas. Se
puede activar el historial de búsquedas, en el que aparecen las últimas
búsquedas efectuadas. Esto facilita la repetición de versiones levemente
modificadas de búsquedas anteriores.

<p>Por último, se puede controlar el número de aciertos obtenidos y su
presentación en pantalla.

}

_texttanumbrowseoptions_ [l=es] {Existen _numbrowseoptions_ manera(s) de encontrar información en esta colección:}

_textsimplehelpheading_ [l=es] {¿Cómo encontrar información?}

_texthelpscope_ [l=es] {

<p>_iconblankbar_
<a name=scope-of-queries>
<h3 align=left>Campo de acción de las búsquedas</h3> 

<p>En la mayoría de las colecciones puede usted escoger diferentes
índices para la búsqueda. Por ejemplo, puede haber índices por autor o
por título. También puede haber índices por capítulo o por párrafo. Por
lo general, se obtiene el documento correspondiente cualquiera que sea
el índice utilizado.

<p>Si los documentos son libros, éstos aparecerán en el lugar
predefinido.

}
